@@ -163,6 +163,9 @@ class Data:
     # Текст в ejabberd.cfg - имена хостов с которыми работает сервис
     sr_jabber_hosts_pass = {}
 
+    # Текст в ejabberd.yml - имена хостов с которыми работает сервис
+    sr_jabber_hosts_yml = {}
+
     # jabber id пользователя
     sr_jabber_user_id = {'mode':"w"}
 
